package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````#``0````!```@'````#0``,$8```````T`"``
M"``H`!H`&0````8````T````-````#0```$````!``````0````$`````P``
M`30```$T```!-`````T````-````!`````$````!``````````````````"S
MD```LY`````%```@``````$``+R(``#<B```W(@```.0```#I`````8``"``
M`````@``O)```-R0``#<D````1````$0````!@````0````$```!1````40`
M``%$````1````$0````$````!&1TY5$`````````````````````````````
M``8````09'3E4@``O(@``-R(``#<B````W@```-X````!`````$O;&EB+VQD
M+G-O+C$`````````!````!0````#1TY5`(MD"2QHKG^>:&*?PN4]#930CF.G
M````!````!`````!1TY5```````````#`````@````````!#````8@``````
M````````7`````P````I````00`````````\`````````$````!"````1P``
M`#T```!;````"P```#H````N`````````"\````:``````````````!/````
M&P```%4````$````5P```&````!6````4@````````````````````````!-
M````)@```!X`````````4````#D`````````*@````````!&````7P```"L`
M```4````1`````````!.````*````"P`````````7@```#@````S````#P``
M``````!%````6@````D````^````)````$@````V````-0```$H`````````
M````````````````````````````````````````````````````````````
M````"@```````````````@````X`````````````````````````$0``````
M````````!@```!``````````70```!@``````````````!(`````````#0``
M`!,`````````%P```",````'```````````````@````````````````````
M)0````````!8````20```"$````````````````````6`````````#<```!1
M`````P```$P```!4`````````"(````R````/P````````!9````2P``````
M```[````-````$,`````````&0```&$``````````````#``````````!0``
M`````````````````!P````M````4P```#$````=```````````````G````
M```````````(```````````````?````%0```!$```!(````"`````@$$!``
M@`1`)00``"B$`(:@`@"!@`@$*`M!$H`X"```B@````````!(````2P```$X`
M``!/````5P```%@```!9`````````%L```!<````70```%X```!?````80``
M````````']_%;BU'WLY\FG]KMIO%+@[D_R!\U&35'%AQV0'&1^*'U_I"P.-+
MK'R2X[HL/^7"8&RA^F^+`;*;PT^9UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5
M"Y<Z#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````&*P`
M`````P``#````HX``````````!(```````+F```````````2```````"&0``
M````````$@```````=P``````````!(```````)\```````````2```````"
M#@``````````$@```````!```````````"````````,&```````````1````
M```#F0``````````$@```````IX``````````!$```````'R```````````2
M````````Z0``````````$@```````<P``````````!(```````+?````````
M```2```````#(@``````````$0```````FT``````````!(```````%-````
M```````2```````""```````````$@```````(<``````````!(```````#D
M```````````2```````!I```````````$@```````M$``````````!(`````
M``'K```````````2```````!/P``````````$@```````,8``````````!$`
M``````)````````````2```````!#0``````````$@```````&,`````````
M`!8```````*L```````````B```````!>P``````````$@```````Q``````
M`````!(```````(H```````````2```````!:```````````$@```````DD`
M`````````!(```````%T```````````2```````!&P``````````$@``````
M``$``````````"````````&U```````````2```````!A@``````````$0``
M`````KL``````````!(```````!4```````````2```````"`0``````````
M$@```````)8``````````!(```````"B```````````2```````!-```````
M````$@```````L(``````````!(```````(3```````````2````````^@``
M````````$@```````NT``````````!(```````*E```````````2````````
M1@``````````$@```````.X``````````!(```````%=```````````2````
M````TP``````````$@```````M@``````````!(```````'Z```````````2
M```````"+P``````````$@```````'8``````````!(```````'C````````
M```2````````MP``````````$@```````2L``````````!(```````&Z````
M```````2```````!P@``````````$@```````E\``````````!(````````L
M```````````@```````"_@``````````$@```````P@``````````!$`````
M``'3```````````2```````"R0``````````$@```````E$``````````!(`
M``````.B```Z4````,82```.```#S@``,3@```9L$@``#@```HD``!VL```"
M;A(```X```-V```GN`````82```.```$.0``)[X```':$@``#@```U8``#>D
M```"K!(```X```0E``#@&``````0```7```#M0``*9@````H$@``#@```]L`
M`&[X```!7!(```X```&5``!S+@````01```0```$"0``X"P`````$```%P``
M!#$``";(````0!(```X```1&```P?````+P2```.```$6```+GX```!B$@``
M#@``!&8``"[@````-!(```X```/F``#@```````0```6```#P@``*<````#.
M$@``#@```ZX``.`8`````!```!8```-L``#@$@````01```6```#[```(!P`
M````$@``#@``!&X``&Z:````7A(```X```/H``#@```````@```6```#AP``
M,&(````:$@``#@```_,``"<(````L!(```X```0;``!P5````I02```.```$
M#@``*HX```/P$@``#@!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E
M<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,
M7VUE;6]R>5]W<F%P`%])3U]S=&1I;E]U<V5D`%]?<W1A8VM?8VAK7V9A:6P`
M97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T
M`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R
M96%D`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T-C1?=&EM
M938T`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?
M8VAK`%]?;38X:U]R96%D7W1P`%]?;&EB8U]S=&%R=%]M86EN`%]?<W1A=#8T
M7W1I;64V-`!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M
M96US970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E
M<G)N;U]L;V-A=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T
M9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S@`;&EB8RYS
M;RXV`&QD+G-O+C$`6%-?26YT97)N86QS7U!!4E]"3T]4`&UY7W!A<E]P;`!P
M87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]E9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!?96YD`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?
M<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET`$=,24)#7S(N-`!'3$E"
M0U\R+C(`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXQ,@!'3$E"
M0U\R+C$`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP`$=,24)#7S(N,S0`````````
M`@`#``0`!0`"``,``0`#``,``P`#``,``P`#``8`!P`!``,``0`!``@``P`#
M``$``0`#``$``0`)``$`"@`#``$``P`#``$``0`#``$``P`!``,``0`!``$`
M`P`#``$``P`#``$``0`!``$``P`#``(``0`#``$``0`%``L`!``!``,``P`#
M``,`!``!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$````!``$```-.````$````"`-:6D4````!@``!'<`````
M``$`"0```T0````0``````UI:1(````+```$@0```!`):1ER````"@``!(L`
M```0"6D?<P````D```27````$`UI:10````(```$=P```!`&EI&2````!P``
M!*,````0#6EI$0````4```2N````$`EI&70````$```$N````!`-:6D0````
M`P``!,0````0!I:1M`````(```3.````````W(@````6```A"```W(P````6
M```@Q```WJ`````6``!UHP``WJ0````6```=K```WJP````6``#@&```WKP`
M```6``#@!```WL@````6``#@&```WM`````6```WI```WMP````6``#@&```
MWN`````6``#@'```WN0````6``!S.```WNP````6``!S1P``WO`````6``!V
M!```WO0````6``!S8P``WO@````6```F7```WOP````6``"S@@``WP`````6
M``!S0P``WP0````6``!S>```WP@````6``!SA```WPP````6``!SA@``WQ``
M```6``!SCP``WQ0````6``!SG```WQ@````6``!SG@``WQP````6``!TIP``
MWR`````6``!SH```WR0````6``!SJ0``WR@````6``!SL0``WRP````6``!S
MN@``WS`````6``!S,@``WS0````6``!ST0``WS@````6``!SW0``WSP````6
M``!SYP``WT`````6``!S\0``WT0````6``!S^P``WT@````6``!T#```WTP`
M```6``!T'@``WU`````6``!T*0``WU0````6``!T.0``WU@````6``!T2@``
MWUP````6``!T3```WV`````6``!T60``WV0````6``#@"```WV@````6``!T
M90``WVP````6``!T=0``WW`````6``!T?```WW0````6``!T%P``WW@````6
M``!T@0``WWP````6``!T-```WX`````6``!TB0``WX0````6``!TC0``WX@`
M```6``!TD@``WXP````6``!TFP``WY`````6``!TH```WY0````6``!TI0``
MWY@````6``!TK@``WYP````6``!TZ0``WZ0````6``!U/```WZ@````6``!U
M00``WZP````6``!U1@``W[`````6``!U40``W[0````6``!U8```W[@````6
M``!U;@``W[P````6``!U?P``W\`````6``!U@0``W\0````6``!UA@``W\@`
M```6``!UB```W\P````6``!UG0``W]0````6``!UQ```W]@````6``#@(```
MW]P````6``#@)```W^`````6``!SP0``W^0````6``!V!0``W^@````6``!V
M"```W^P````6``#@*```W_`````6``!T<```W_@````6``#@$@``W_P````6
M``!S@0``X`0````6``#@!```X!(````6``!V"P``WJ@``"84````````WK``
M``@4````````WK0``$(4````````WK@``!X4````````WL```$04````````
MWL0``!`4````````WLP``!(4````````WM0```L4````````WM@``#$4````
M````WN@``"@4````````WZ```#L4````````W]```!TJ````````W_0``!H4
M````````W:P```(5````````W;````,5````````W;0```05````````W;@`
M``45````````W;P```85````````W<````<5````````W<0```H5````````
MW<@```P5````````W<P```T5````````W=````X5````````W=0```\5````
M````W=@``!$5````````W=P``!(5````````W>```!,5````````W>0``!05
M````````W>@``!45````````W>P``!85````````W?```!<5````````W?0`
M`!@5````````W?@``!D5````````W?P``!L5````````W@```!P5````````
MW@0``!X5````````W@@``!\5````````W@P``"`5````````WA```"$5````
M````WA0``"(5````````WA@``",5````````WAP``"05````````WB```"45
M````````WB0``"85````````WB@``"<5````````WBP``"D5````````WC``
M`"H5````````WC0``"L5````````WC@``"P5````````WCP``"T5````````
MWD```"X5````````WD0``"\5````````WD@``#`5````````WDP``#$5````
M````WE```#(5````````WE0``#,5````````WE@``#05````````WEP``#45
M````````WF```#85````````WF0``#<5````````WF@``#@5````````WFP`
M`#D5````````WG```#H5````````WG0``#L5````````WG@``#P5````````
MWGP``#T5````````WH```#X5````````WH0``#\5````````WH@``$`5````
M````WHP``$$5````````WI```$,5````````WI0``$45````````WI@``$85
M````````WIP``$<5`````$Y6```O#4O[`7```,3L2K4!<````0AG!F'_```"
M>BIN__Q.7DYU```O.P%P``#$SD[[`7$``,3*`````$[[`7$``,3"+SP`````
M8/_____<3OL!<0``Q+(O/`````Q@_____\A.^P%Q``#$HB\\````&&#_____
MM$[[`7$``,22+SP````D8/____^@3OL!<0``Q((O/````#!@_____XQ.^P%Q
M``#$<B\\````/&#_____>$[[`7$``,1B+SP```!(8/____]D3OL!<0``Q%(O
M/````%1@_____U!.^P%Q``#$0B\\````8&#_____/$[[`7$``,0R+SP```!L
M8/____\H3OL!<0``Q"(O/````'A@_____Q1.^P%Q``#$$B\\````A&#_____
M`$[[`7$``,0"+SP```"08/____[L3OL!<0``P_(O/````)Q@_____MA.^P%Q
M``##XB\\````J&#____^Q$[[`7$``,/2+SP```"T8/____ZP3OL!<0``P\(O
M/````,!@_____IQ.^P%Q``##LB\\````S&#____^B$[[`7$``,.B+SP```#8
M8/____YT3OL!<0``PY(O/````.1@_____F!.^P%Q``##@B\\````\&#____^
M3$[[`7$``,-R+SP```#\8/____XX3OL!<0``PV(O/````0A@_____B1.^P%Q
M``##4B\\```!%&#____^$$[[`7$``,-"+SP```$@8/____W\3OL!<0``PS(O
M/````2Q@_____>A.^P%Q``##(B\\```!.&#____]U$[[`7$``,,2+SP```%$
M8/____W`3OL!<0``PP(O/````5!@_____:Q.^P%Q``#"\B\\```!7&#____]
MF$[[`7$``,+B+SP```%H8/____V$3OL!<0``PM(O/````71@_____7!.^P%Q
M``#"PB\\```!@&#____]7$[[`7$``,*R+SP```&,8/____U(3OL!<0``PJ(O
M/````9A@_____31.^P%Q``#"DB\\```!I&#____]($[[`7$``,*"+SP```&P
M8/____T,3OL!<0``PG(O/````;Q@_____/A.^P%Q``#"8B\\```!R&#____\
MY$[[`7$``,)2+SP```'48/____S03OL!<0``PD(O/````>!@_____+Q.^P%Q
M``#",B\\```![&#____\J$[[`7$``,(B+SP```'X8/____R43OL!<0``PA(O
M/````@1@_____(!.^P%Q``#"`B\\```"$&#____\;$[[`7$``,'R+SP```(<
M8/____Q83OL!<0``P>(O/````BA@_____$1.^P%Q``#!TB\\```"-&#____\
M,$[[`7$``,'"+SP```)`8/____P<3OL!<0``P;(O/````DQ@_____`A.^P%Q
M``#!HB\\```"6&#____[]$[[`7$``,&2+SP```)D8/____O@3OL!<0``P8(O
M/````G!@____^\Q.^P%Q``#!<B\\```"?&#____[N$[[`7$``,%B+SP```*(
M8/____ND3OL!<0``P5(O/````I1@____^Y!.^P%Q``#!0B\\```"H&#____[
M?$[[`7$``,$R+SP```*L8/____MH3OL!<0``P2(O/````KA@____^U1.^P%Q
M``#!$B\\```"Q&#____[0$[[`7$``,$"+SP```+08/____LL3E;_\$CG,#Q+
M^P%P``"_ZBUN``S_]"UN`!#_\"9U`7````$D+5/__$AN__!(;O_T2&X`"&'_
M___]FB`U`7````$X+P`O`"\U`7````(`8?\``%3L('4!<````E1/[P`82A!G
M``$(8?____NPT?4!<````C`@4``H``,#1"0N``A6@B`N``A8@`R`/____V(`
M`8;EB"\`8?____RL(G4!<````CPBB"AN__0@E"%U`7````)$``0B=0%P```"
M6"%1``@A=0%P```"2``,(BX`"%B/<`&P@6P``51#[``$1>@`$"`!Y8C0C"39
ML\!F^E:!0K`<`$*G+P@O`B\U`7````%8)'4!<````DPO$F'____]LD_O`!1*
M@&<``(@O$F'____[F"0`)@Y1@R\#+S4!<````91A_P```BY/[P`,2HAG``"2
M+Q)A____^R!A_____4I8CR(N__P@$["!9@`!"B`"3.X\#/_83EY.=6'____[
MFB)U`7````),(HAG``#@+PAA____^M!A____^H[1]0%P```","!00B@&'EB/
M8`#^QB\28?____VZ6(\O$F'____[""0`)@Y1@R\#+S4!<````91A_P```9Y/
M[P`,2HAF`/]R*'4!<````C@@5$J(9PXO"&'_```:OEB/8`#_5B\#+S4!<```
M`6QA_P```6@HB%"/9P#_/B\(8?\``!J86(]@`/\P+S4!<````4@O-0%P```"
M7&'____[Y'($0K`<`$*G+P@O`B\U`7````%8)'4!<````DPO$F'____\=$_O
M`!1*@&8`_L1@`/]&2'@``6'____[1&'____Z$DYQG<X@'R!/2%=(44*G0J=+
M^P%P``"]=$A0+P`O-0%P```!!&'____X^$K\3G$O#4O[`7```+U4(#4!<```
M`0PB-0%P```!*+*`9Q(@=0%P```!$$J(9P8O`4Z06(\J7TYU+PTO`DO[`7``
M`+T>(#4!<````0PB-0%P```!*)"!)`#D@M"`D8!$@-""XH!G%"!U`7````$4
M2HAG""\`+P%.D%"/)!\J7TYU+PTO"DO[`7```+S6)'4!<````3Q*$F8F2K4!
M<````1AG$B!U`7````$<+Q!A____^:Y8CV'_____3A2\``$D7RI?3G5@____
M_W).<4CG(#Y+^P%P``"\BBAO`!Q*C&=X('4!<````2`L4$J.9VH0%"!,0H)*
M`&<0#```/6<&4H@0$&;T)`B4C"162HIG)B9.+P(O#"\*8?____P`3^\`#$J`
M9@@,,@`]*`!G$EB+)%-*BF;<($H@"DS??`1.=9?.(`OD@"!O`"`@@$7R*`$@
M2B`*3-]\!$YUE<H@2B`*3-]\!$YU3E;_D$CG("1+^P%P``"[[B0N``@D=0%P
M```!)"U2__Q(;O^0+P)A____^NQ0CTJ`9BXB+O^@`H$``/``#($``$``9R`,
M@0``H`!G&"!N__PB$K*(9B9,[B0$_X1.7DYU0H!@Z$AX``(O`F'____Z@%"/
M2H!7P$G`1(!@T&'____X`DY6_XQ(YS`\2_L!<```NVPF;@`(*'4!<````20M
M5/_\2HMG!$H39A8B+O_\(!2P@68``7!,[CP,_W1.7DYU+PMA____^Q@D"%B/
M9]PO`F'____ZNEB/2HAG``"<1>@`$PP2`"YG``"F+PMA____^/HM0/^,+HIA
M____^.Y8CR!N_XQ(<`@"8?____AF)@@O"B\++S4!<````9!(>/__2'@``2\(
M8?____K(2&[_D"\#8?____8,3^\`)%*`9Q0@+O^@`H```/``#(```$``9P``
MNB\#8?____=06(\O`V'____V?EB/+P)A____^B!8CTJ(9@#_:"\"8?____I,
M+PMA____]L!0CV``_QY**@`!9P#_.@P2`"YF`/].#"H`+@`!9@#_1$HJ``)G
M`/\@+PMA____^#0M0/^,+HIA____^"A8CR!N_XQ(<`@"8?____>@)@@O"B\+
M+S4!<````9!(>/__2'@``2\(8?____H"2&[_D"\#8?____5&3^\`)%*`9P#_
M3F``_S8O`V'____^<EB/+P-A____]<98CV``_T9A____]EI.5O_T2.<^/$O[
M`7```+G$*&X`""1N``PF-0%P```!)"!#+5#__`P2`#UG``"T+PIA____]XQ8
MCRU`__1(;O_X+PQA_____/HD"%"/9P``MB\(8?____=J6(^PKO_T9```_B@N
M__CEC"9U`7````$@$A0@3&<``3(,`0`]9P92B!(09O21S"03U(0B;O_T2'&(
M`F'____VLB)"(HA8CV<H(%,B<$@`$!P2@&<0($E2B0P``#UG"!`<$H!F\"!)
M$/P`/1`:$,!F^B(N__P@0R`0L(%F``#N3.X\?/_03EY.=5**+PIA____]MA8
MCRU`__1(;O_X+PQA_____$8D"%"/9@#_3B9U`7````$@*A,B14J19P``FB!%
M0H)8B"`"4H)*D&;V5H#EB"!U`7````%`2I!G/B\`+P5A____]?@L"":(4(]G
M@B@"Y8P@1D*P+`0M0O_X$A0@3&8`_QY@2B!"$!H0P&<`_V(0&A#`9O)@`/]8
M<@$@@2\`8?____7,+`A8CV<`_T0H`N6,+P0O!2\(8?____00)H9/[P`,($9"
ML"P$+4+_^&"LD<A@`/[:<`A"@B!U`7````%`2I!GM&``_W1A____]))/[^_\
M2.<\)$O[`7```+?\*"\0("HO$"0D=0%P```!)"]2$!A(>`__=AS6CR\#+S4!
M<````41A____]*8D`$_O``QO#%.`2C<H%V8X2H!F,B\%+P1A____\]31]0%P
M```","\08?____2,3^\`#"(O$!@@$K"!9D1,WR0\3^\0!$YU)``O`DAX`"\O
M`V'____V"$_O``Q*B&>V+P(O`R\$8?____.(T?4!<````C`O$&'____VK$_O
M`!!@LF'____ST"\-+PI+^P%P``"W/B\U`7````%<+S4!<````2PO-0%P```!
M3&'____S0B1U`7````(PU<@O$F'____U.$*G(#4!<````5`O`"\`+S4!<```
M`3`O-0%P```!5"\28?____7&3^\`*"1?*E].=2\-2_L!<```MM0O-0%P```!
M7"\U`7````$L+S4!<````4QA____\MC1]0%P```","\08?____303^\`$"I?
M3G5/[]_X2.<@/$O[`7```+:.*'4!<````20O5"`88?____.V+S4!<````6`O
M`"\U`7````%D2'@0`4AX``%%[P`J+PIA____]DQ(>!``)`\&@@``$#,O`B\*
M8?____,6)$!/[P`D2H!M/DAJ``%A____\Z(F2%B/2HAG%"\*+P(O"&'____R
M)D(SJ`!/[P`,(B\@&"`4L(%F$B!+(`M,WSP$3^\@"$YUE\M@Y&'____R=&#_
M____3D_O[Y!(YS\^2_L!<```M=@D+Q"@)B\0I"AU`7````$D+U00F'HLVH\O
M!2\U`7````%L8?____D>)DA(>``O+P)A____\VA/[P`02HAG+"\"+S4!<```
M`7!A____^[I0CR!"(B\0F"`4L(%F``%H(`A,WWS\3^\0<$YU+P-A____\6`F
M-0%P```!="\#+PAA____]%HD2$_O``Q*B&>P+C4!<````7@L-0%P```!?"@/
M!H0```"82A)G``"R2HMG$B\*+PMA____\'A0CTJ`9P``@B\*8?____+\6(\L
M0$/R"/^SRF,:#!$`+V8(0A%3B;/*9O(O"F'____RVEB/+$`O`F'____RSEB/
M0?8(`;#\#_]B`/\Z+P(O!R\*+P9(>!``2'@``2\$8?____2P+P4O!&'____O
M]D_O`"1*@&82("\`/`*```#P``R```"``&<T+P-"IV'____SDB1(4(]*B&<`
M_NI*$F8`_U)*BV<&#!,`+F="/'P``21U`7````%H8`#_?$AX``$O!&'____S
M2%"/2H!FNB\$+S4!<````7!A____^G`O!&'____P,D_O``Q@`/ZL2BL``6:X
M+P-"IV'____S)B1(4(]*B&:68`#^?&'____PE"\")"\`"$AX`"\O`F'____S
M/E"/2HAG!"0(4H(O0@`()!]@____[^!/[^_\2.<@/$O[`7```+/6)F\0'"AU
M`7````$D+U00%$J+9WY*$V=Z+PMA____\:18CR0`4H`,@```$`!B``"&1>\`
M%"\`+PLO"F'____OI$'R*/]/[P`,M<AD#@P0`"]F"$(04XBUR&;R2'@`+R\*
M8?____*R4(]*B&<FM<AD`D(0+PIA____[U98CR(O$!0@%+"!9C(@"$S?/`1/
M[Q`$3G4B+Q`4(!2P@68<+W4!<````6@0'$S?/`1/[Q`$8/___^\<D<A@Q&'_
M___OGE&/2.<_-$O[`7```+,*)G4!<````20O4P`H="34CR8U`7````&`)'4!
M<````2`O`B\#8?____9.4(]*B&<H("\`).6((%+1P"`H``0@@&?>6(@@*``$
M((!GU%B(("@`!""`9NQ@R"8U`7````&$)'4!<````2`O`B\#8?____8&4(]*
MB&<H("\`).6((%+1P"`H``0@@&?>6(@@*``$((!GU%B(("@`!""`9NQ@R"8U
M`7````&()'4!<````2`O`B\#8?____6^4(]*B&<H("\`).6((%+1P"`H``0@
M@&?>6(@@*``$((!GU%B(("@`!""`9NQ@R"8U`7````&,)'4!<````2`O`B\#
M8?____5V4(]*B&<H("\`).6((%+1P"`H``0@@&?>6(@@*``$((!GU%B(("@`
M!""`9NQ@R"8U`7````)`)'4!<````2`O`B\#8?____4N4(]*B&<H("\`).6(
M(%+1P"`H``0@@&?>6(@@*``$((!GU%B(("@`!""`9NQ@R"@U`7````&4)'4!
M<````2`O`B\$8?____3F4(]*B&<H("\`).6((%+1P"`H``0@@&?>6(@@*``$
M((!GU%B(("@`!""`9NQ@R"@U`7````%L)'4!<````2`O`B\$8?____2>4(]*
MB&<H("\`).6((%+1P"`H``0@@&?>6(@@*``$((!GU%B(("@`!""`9NQ@R"PU
M`7````&8)'4!<````2`O`B\&8?____164(]*B&<H("\`).6((%+1P"`H``0@
M@&?>6(@@*``$((!GU%B(("@`!""`9NQ@R"HU`7````&<)'4!<````2`O`B\%
M8?____0.4(]*B&<H("\`).6((%+1P"`H``0@@&?>6(@@*``$((!GU%B(("@`
M!""`9NQ@R"XU`7````&@)'4!<````2`O`B\'8?____/&4(]*B&<H("\`).6(
M(%+1P"`H``0@@&?>6(@@*``$((!GU%B(("@`!""`9NQ@R"XU`7````%P)'4!
M<````2`O`B\'8?____-^4(]*B&<H("\`).6((%+1P"`H``0@@&?>6(@@*``$
M((!GU%B(("@`!""`9NQ@R"\"+S4!<````:1A____\T!0CTJ(9PPO""\%8?__
M__7R4(\O`B\U`7````&H8?____,>4(]*B&<2+P@O-0%P```!K&'____URE"/
M+P(O-0%P```!L&'____R]E"/2HAG,"\(+P1A____]:A0CR\U`7````&X+P-A
M____]990CR(O`"@@$["!9BQ,WRS\4(].=2\"+S4!<````;1A____\K!0CTJ(
M9\8O""\&8?____5B4(]@N&'____KKDY6__@O#2\*2_L!<```KQ@D=0%P```!
M)"U2__Q(;O_X+S4!<````9AA____\FA0CTJ(9R00$&<@#```,%;`2<!$@"!N
M__PB$K*(9A`D;O_P*F[_]$Y>3G5"@&#F8?___^M,3E8``"\-2_L!<```KKA(
M;@`,+RX`"$AX``$@=0%P```!-"\08?___^H*2'@`_V'____L1-_\__[_]$CG
M/SQ+^P%P``"N@"@W`7```0`X)G4!<````20ODP%P``$`,$AX``)"IT*G+P1A
M____[=9T_W;_UH'5@"`"`H"`````(@,"@0``__]/[P`02H!M``"TEH&5@&MV
M2>\`*"1U`7````'$0J<O`R\"+P1A____[91/[P`0>O]\_YR!FX!G``"P+SP`
M`0`(+PPO!&'____IH$_O``Q\_[R`9P``AG('LH!D%$'T"/BYR&(,*A"ZDF<Z
M4XBYR&/T</\&@___``#5@'K_?/]&1IR#FX)FEG#_<O\B=P%P``$`,"!3L<EF
M7DS?//S?_``!``Q.=2PH``2\J@`$9KR1S"((6\!)P-*#T8)@SD*%4X&1A7S_
M0H<N`0"'__\``$*`<@'2A]&&8`#_,B\U`7````'`8?____Z6+S4!<````;QA
M_____HAA____Z<IA____Z=@O`&'____H]%B/2HAG`B!0(`A.=4Y6__A(YS@\
M2_L!<```K1HF+@`()G4!<````20M4__\2&[_^"0U`7````'(+P)A____\&0D
M2%"/2HAG!$H09B`O`R\"8?____,04(\B+O_\(!.P@69@3.X\'/_<3EY.=2\#
M8?___^JP*$`NBF'____JIEB/2'0(`F'____J(B@(+PHO-0%P```!="\#+S4!
M<````7Q(>/__2'@``2\(8?___^Q\3^\`'"Z$+P)A____\JA0CV"68?___^CT
M3^__+$CG/SY+^P%P``"L7BAO`00F=0%P```!)"]3`/PO=0%P```!T`"<+W4!
M<````6@`H$*O`*0O=0%P```!U`"X+W4!<````=@`O"]U`7````'<`,`O=0%P
M```!X`#$0J\`R"]U`7````'D`*@O=0%P```!Z`"L0J\`L'0PU(\O`B8U`7``
M``%L+P-A____[TI0CTJ(9P9*$&8``IIA____Z&0O`&'____G@%B/2HAG``&\
M)%!*BF<``;0O"F'____IF%B/T(!2@"\`8?___^D2+$@0$EB/*`A*`&<N*C4!
M<````>P"@````/\O`"\%2'C__TAX``$O#F'____K9%**5(X0$D_O`!1FVDWO
M`+@@-0%P```!K"\"+P!A____[KI0CTJ(9P9*$&8``1`@'F;F3>\`G"1>2HIG
M)$H29P`!AB\*8?___^\J6(]*@&?F+PIA____YQ`D2%B/2HAGUB\*8?___^CT
M+$`NA&'____HZDWV"2`$!"P.+HYA____Z&(L2"\$+S4!<````?`J-0%P```!
M>"\%+PHO-0%P```!]$AX__](>``!+PAA____ZK)/[P`D2'@!P"\.8?___^C^
M4(]2@&808?___^D:(!!R$;*`9@`#%B\"+PYA____Z:8H`%"/9A0@+P!``H``
M`/``#(```$``9P`!;"\.+Q0O-0%P```!_$AX``$@=0%P```!-"\08?___^GX
M3^\`%)7*(B\`_"`3L(%F``0L($H@"DS??/Q/[P#43G4O""](`#!A____[BQ8
MCR!O`"Q*@&<`_MPO"&'____F#"1(6(]*B&8`_OQ-[P"<8`#^RDWO`*@@'F<J
M+P(O`&'____M7%"/2HAG[$H09^@O"&'____EUB1(6(]*B&8`_B(@'F;62'@`
M#6'____G.BQ(6(\H""1U`7````',<%,J-0%P```![&``_B*5RB\*8?___^>,
M+$`NA&'____G@DWV"2`$!"P.+HYA____YOHL2"\$+S4!<````?`J-0%P```!
M>"\%+PHO-0%P```!]$AX__](>``!+PAA____Z4I/[P`D2'@!P"\.8?___^>6
M4(]2@&8`_JA@`/Z4+P@O2``P8?____P&6(\B+P#\(!,@;P`LL(%F``,&+T@!
M!$S??/Q/[P#48/___^4"+B\`2&'____EF+"'9@#^B"`O`$`"@````?\,@```
M`<!F`/YT+P9A____YE(D2"\"+S4!<````E!A____[#A/[P`,2HAG``%L+P@O
M%&'____RTBP(4(]G``%:+P9A____YI18CRX`<`.PAV0N+S4!<````@0@1DAP
M>/QA____X^)0CTJ`9A1P!+"'9P`"*B!&##``+WC[9P`"'B\")#4!<````9@O
M`F'____KRE"/2HAG``$&$!!G``$`#```,&<``/@O-0%P```!N"\"8?___^YF
M8?___^5J)#4!<````5`O`B\`+P4O#B\U`7````(42'C__TAX``$O"F'____G
M_D_O`"@H=0%P```"&$AX`<`O"F'____F0E"/4H!F1F'____F7G`1L)!F.E*$
M8?___^40+P(O!"\`+P4O#B\,2'C__TAX``$O"F'____GL$_O`"1(>`'`+PIA
M____Y?Q0CU*`9[HO#F'____C@B\*+P-A____[<(O"F'____Z9$_O`!!@`/TX
M+P`O#B\4+S4!<````?A(>``!('4!<````30O$&'____G!D_O`!B5RF``_0PL
M%&``_J1"IR\&8?___^+(*$!0CTJ`9P#^^"\`8?____BF+``N`5B/2H9M`/[D
M0J=P_W+VTH?1AB\!+P`O#&'____FD$AX``9![P#A+P@O#"](`$AA____XJ9/
M[P`<(&\`+%V`9@``X`R0`$-!0V8`_J`,:$A%``1F`/Z60J=P_W+.TH?1AB\!
M+P`O#&'____F0DAX`"@D#P:"````YR\"+PQA____XEA/[P`<<BBR@&8``)1"
M+P#[+S4!<````5`O`B\%+PXO-0%P```"$$AX__](>``!+PIA____YFY/[P`@
M+PYA____XE(O"B\#8?___^R2+PIA____^31/[P`08`#\""AL``1*C&<`_=PO
M#&'____D+EB/<@.R@&0`_<HO-0%P```""$AT"/QA____X7Y0CTJ`9@#]L"P,
M8`#]JF'____BEB\U`7````(,8?____=`48](YS`\2_L!<```I?0D=0%P```!
M)"]2`!QA____X@31]0%P```","90%VL`9@!G=!C4CR\"+S4!<````D!A____
MZ2Q0CTJ(9P@,$``Q9P`!IF'____REF'____AQM'U`7````(P)E!(>``#2'@`
M`2\U`7````(<+PMA____XPPF2$_O`!!*B&<Z+S4!<````B`@:``,+Q!A____
MX88H=0%P```",-G(+Q1A____XCP@:P`,(%!/[P`,""@`!@`)9@`!U$AX``-(
M>``!+S4!<````B1A____X4HH=0%P```",-G(+Q1A____XJ`F2$_O`!!*B&<L
M+P(O-0%P```!<&'____H:E"/2HAG``$,+P@@:P`,+Q`O%&'____ASD_O``Q(
M>``!+S4!<````BAA____X/`F=0%P```",-?(+Q-A____XKXO-0%P```"+"\(
M+Q-A____X90@4T(H`&<O`B\U`7````%L8?___^@")`@F=0%P```".":(3^\`
M(&=02'@!P"\"8?___^+((@!2@5"/=@&V@60D<A&R@&<>+P`O`B!U`7````(\
M(%`O$"\U`7````(T8?___^)<(B\`'"`2L(%F``#@3-\\#%"/3G4@=0%P```"
M/"\08?____>X)`@FB%B/9I@O-0%P```!`&'____B(DHH``%G`/YL8?____#J
M8?___^`:T?4!<````C`F4&``_E(@=0%P```"/"!0+Q`@:P`,+Q!A____Z\I0
MCTAX``$O-0%P```"*&'____?X"9U`7````(PU\@O$V'____AKB\U`7````(L
M+P@O$V'____@A"!30B@`9R\"+S4!<````6QA____YO(D""9U`7````(X)HA/
M[P`@9@#^\&``_SPO""\48?___^(84(]@`/X@8?___]_<3E;_^$CG(#1+^P%P
M``"C1B9N``@D=0%P```!)"U2__Q(;O_X+S4!<````9AA____YI)0CTJ(9Q(0
M$&<.#```,&<(2HMG!$H39A0B+O_\(!*P@69L3.XL!/_H3EY.=2\+8?___^\.
M)`A(>``O+PAA____XB1/[P`,2HAG!"0(4H(O`F'____>R$AX``0O-0%P```!
M\"\(8?___^)T3^\`$$J`9J8B+O_\(!*P@682+4L`"$SN+`3_Z$Y>8/___^<>
M8?___]\63G%/[_TD2.<_/DO[`7```*)^+V\##`!<+W4!<````20`@"!O`(`O
M4`,$,GP`.-/O`%PB#P:!````A#1\`'C5[P!<($$@$2%I``0`#%")0I`A0``$
M0J@`"$'H`!"SRF;D*&\`["XO`/`D;P#T)B\`^")O`/PH+P$`)"\`A"`O`(@L
M;P",)F\`D#!\`!#1P0:!```"$"]!`%0B#"A#+T``0"]+`#@F""P0*B@`!%"(
M)D,@*P`PO8`F*P`TNX.Q@;^#M8$@+P!`L8,D"2`$TH'CFY/)*`.(@4*H`&@A
M1`!L(@HN#"1"*$`D#B]O`#@`0+'O`%1G5BQ&+T4`."8(+!`J*``$4(@F0R`K
M`#"]@"8K`#2[@[&!OX.U@2`O`$"Q@R0)(`32@>.;D\DH`XB!0J@`:"%$`&PB
M"BX,)$(H0"0.+V\`.`!`L>\`5&:J(&\`7"]0`#`O:``$`#0O:``(`&`O:``,
M`&0O:``0`%0O:``4`%@O:``8`&@O:``<`&PO:``@`'@O:``D`'P@+P`PZX@B
M+P`TZYE"@D*#)@&&@"`O`(0B+P"(0H0&@5J">9G1A"HO`'C2KP!\T872@]&"
M)"\`6"PO`&R]@L2O`&0@!K6`0H1"A2H!VH`B+P!DY(D@+P!@?A[OJ("!(B\`
M9.^I)"\`8"8O`&3BBN*3XHKBDX""+$""@RA!E<J7RR9!)"\`C"8O`)!"@`:#
M6H)YF=6`(B\`:-:O`&S5@2XO`%0L"KV'+"\`6"`,L8;.KP`PS*\`-"!&+`<B
M+P!4LX8N""`O`%BQA]Z#W8(F!7(;XJLD!.N*A(,F!>N++`.,@D*"0H,F!]:&
M+"\`-.2.+B\`,'`>X:^.AB!'(B\`-.&I+"\`,"XO`#3BCN*7XH[BER`(@(8O
M0`!`@H<O00!,0J\`.$*O`#PO00`\+"\`E"XO`)A"@`:'6H)YF=V`($8B1RPO
M`%0N+P!8(`C>B=V`($8B1R`.(B\`0+.`(@PL+P!,O8'`A,*%+@J_@"P,O8$L
M""X)WH'=@"!&(D<B`WX;[JD@`NN(@($B`^N)@H`@04*`0H$B"=*(+`7DCB)&
M+@1\'NVO+`F,AR!&+@5\'NVO(D?BC.*5XHSBE2X(CH0@1RP)C(4B1D*O`$1"
MKP!(+T8`2"@O`)PJ+P"@0H<&A5J">9G9ARP*+@O>A=V$)$8F1RPO`$`N"+^&
M+B\`3"@)N8?,@LZ#*"\`.+V$*B\`/+^%+`HN"]Z%W80J`7@;Z*TH`.N,B(4J
M`>N-+`6,A$*$0H4J!]J&+`/DCB1&+@)\'NVO+`J.AB9'+@-\'NVO)$<L`BX#
MXH[BE^*.XI<D"X2&+T(`0"8*AH<H0T*O`$Q"KP!0+T,`4"PO`*0N+P"H0H(&
MAUJ">9G=@B0O`#@F+P`\UH?5AB]"`#@O0P`\)@@L+P!`O8,N"20,M8?&@,Z!
M+"\`1+V#)$,D";6')D<L+P`X+B\`/"0*WHO=@B1&)D<N!78;YJ\L!.N.C(<N
M!>N/CH8@1T*&0H<N"]Z()`'DBB!")@!T'N6K)`B$@R9")@%T'N6K)$,D`"8!
MXHKBD^**XI,@0B)#)@L@"(:`+T,`<"(*)`F"@BQ!0J\`.$*O`#PO00`\("\`
MK"(O`+!"@@:!6H)YF=&"($`B02`O`$0B+P!()`C2B=&"($`B028O`$`@+P!P
ML8,D#"(.LX+&A,2%)$(D`R`O`$RQ@B8*(@RS@R`((@G2@]&"($`B028'<AOB
MJR0&ZXJ$@R8'ZXN&@B!#0H)"@R8)UH@@!>2(($`B!'`>X:D@"("!)D`B!7`>
MX:DD02`$(@7BB.*1XHCBD2!`(D$B"R@(@H0O00!`*@H@"8J`*$5"KP!$0J\`
M2"]%`$@H+P"T*B\`N$*`!H5:@GF9V8`@1")%*"\`3"HO`%`@"-J)V8`@1")%
M(B\`<"@O`$"Y@2`.*@R[@,*&P(<D0"`!*"\`.+F`(@HJ#KN!*`@J"=J!V8`@
M1")%(@-Z&^JI(`+KB("!(@/KB8*`($%"@$*!(@G2B"@'Y(P@1"H&>![IK2@(
MB(4F1"H'>![IK21%*`8J!^*,XI7BC.*5($0B12H++`B*AB]%`'`N"B@)CH0L
M1T*O`$Q"KP!0+T<`4"HO`+PL+P#`0H<&AEJ">9G;AR!%(D8H+P`X*B\`/"P(
MVHG9AB!$(D4J+P!`+B\`<+^%*`PL#KV$RH+(@R1$*`4N+P!$OX0J"BP,O84L
M""X)WH7=A"!&(D<J`7X;[JTH`.N,B(4J`>N-BH0@14*$0H4J"=J(+`/DCB!&
M+@)\'NVO+`B,AR9&+@-\'NVO)$<L`BX#XH[BE^*.XI<@1B)'+@LD"(Z"+T<`
M0"8*+`F&ABA#0J\`.$*O`#PO0P`\)"\`Q"8O`,A"A@:#6H)YF=6&($(B0R0O
M`$0F+P!(+`C6B=6&($(B0RXO`'`D+P!`M8<L#B8,MX;.@,R!)$8L!R0O`$RU
MABX*)@ZWAR0()@G6A]6&($(B0RX%=AOFKRP$ZXZ,ARX%ZX^.AB!'0H9"ARX)
MWH@D`>2*($(F`'0>Y:LD"(2#)D(F`70>Y:LD0R0`)@'BBN*3XHKBDR!"(D,F
M"R`(AH`O0P!P(@HD"8*"+$%"KP!$0J\`2"]!`$@@+P#,(B\`T$*"!H%:@GF9
MT8(@0")!("\`3"(O`%`D"-*)T8(@0")!)B\`0"`O`'"Q@R0,(@ZS@L:$Q(4D
M0B0#("\`.+&")@HB#+.#(`@B"=*#T8(@0")!)@=R&^*K)`;KBH2#)@?KBX:"
M($-"@D*#)@G6B"`%Y(@@0"($<![AJ2`(@($F0"(%<![AJ21!(`0B!>*(XI'B
MB.*1($`B02(+*`B"A"]!`$`J"B`)BH`H14*O`$Q"KP!0+T4`4"@O`-0J+P#8
M0H`&A5J">9G9@"!$(D4H+P`X*B\`/"`(VHG9@"!$(D4B+P!P*"\`0+F!(`XJ
M#+N`PH;`AR1`(`$H+P!$N8`B"BH.NX$H""H)VH'9@"!$(D4B`WH;ZJD@`NN(
M@($B`^N)@H`@04*`0H$B"=*(*`?DC"!$*@9X'NFM*`B(A29$*@=X'NFM)$4H
M!BH'XHSBE>*,XI4@1")%*@LL"(J&+T4`<"X**`F.A"Q'0J\`.$*O`#PO1P`\
M*B\`W"PO`.!"AP:&6H)YF=N'($4B1B@O`$0J+P!(+`C:B=F&($0B12HO`$`N
M+P!POX4H#"P.O83*@LB#)$0H!2XO`$R_A"H*+`R]A2P(+@G>A=V$($8B1RH!
M?AONK2@`ZXR(A2H!ZXV*A"!%0H1"A2H)VH@L`^2.($8N`GP>[:\L"(R')D8N
M`WP>[:\D1RP"+@/BCN*7XH[BER!&(D<N"R0(CH(O1P!`)@HL"8:&*$-"KP!$
M0J\`2"]#`$@D+P#D)B\`Z$*&!H-:@GF9U88@0B)#)"\`3"8O`%`L"-:)U88@
M0B)#+B\`<"0O`$"UARP.)@RWALZ`S($D1BP')"\`.+6&+@HF#K>')`@F"=:'
MU88@0B)#+@5V&^:O+`3KCHR'+@7KCXZ&($="AD*'+@G>B"0!Y(H@0B8`=![E
MJR0(A(,F0B8!=![EJR1#)``F`>**XI/BBN*3($(B0R8+(`B&@"]#`'`B"B0)
M@H(L04*O`$Q"KP!0+T$`4"`O`.PB+P#P0H(&@5J">9G1@B!`(D$@+P`X(B\`
M/"0(THG1@B!`(D$F+P!`("\`<+&#)`PB#K."QH3$A21")`,@+P!$L8(F"B(,
MLX,@""()TH/1@B!`(D$F!W(;XJLD!NN*A(,F!^N+AH(@0T*"0H,F"=:((`7D
MB"!`(@1P'N&I(`B`@29`(@5P'N&I)$$@!"(%XHCBD>*(XI$@0")!(@LH"(*$
M+T$`0"H*(`F*@"A%0J\`.$*O`#PO10`\*"\`]"HO`/A"@`:%6H)YF=F`($0B
M12@O`$0J+P!((`C:B=F`($0B12(O`'`H+P!`N8$@#BH,NX#"AL"')$`@`2@O
M`$RY@"(**@Z[@2@(*@G:@=F`($0B12(#>AOJJ2`"ZXB`@2(#ZXF"@"!!0H!"
M@2()TH@H!^2,($0J!G@>Z:TH"(B%)D0J!W@>Z:TD12@&*@?BC.*5XHSBE2!$
M(D4J"RP(BH8O10!P+@HH"8Z$+$="KP!$0J\`2"]'`$@J+P#\+"\!`$*'!H9:
M@GF9VX<@12)&*"\`3"HO`%`L"-J)V88@1")%*B\`0"XO`'"_A2@,+`Z]A,J"
MR(,D1"@%+B\`.+^$*@HL#+V%+`@N"=Z%W80@1B)'*@%^&^ZM*`#KC(B%*@'K
MC8J$($5"A$*%*@G:B"P#Y(XB1BX"?![MKRP)C(<@1BX#?![MKR)'XHKBD^**
MXI,N"(Z"($<L"8R#(D9"KP!,0J\`4"]&`%`D+P$$)B\!"$*'!H-:@GF9U8<L
M+P`X+B\`/-Z#W8(D1B9'+B\`<"0(M8<L#B8)MX;.@,R!)"\`1+^")@Z]@RP*
M+@O>@]V")@5T&^2K)`3KBH2#)@7KBRP#C()"@D*#)@?6ABP!Y(XD1BX`?![M
MKRP*CH8F1RX!?![MKR1'+``N`>*.XI?BCN*7(`N`ABA`(`J`AT*O`#A"KP`\
M+T``/"PO`0PN+P$00H$&AUJ">9G=@21&)D<L+P!$+B\`2"(*WHO=@2]&`$0O
M1P!(+`@N#+^&(@FQ@<R$PH4N+P!,OX8D1BP)O8$F02PO`$0N+P!((@K>B]V!
M+T8`1"]'`$@L`WX;[JX@1BP"ZXXB"(R!+@/KCXZ&E<J7RR9'U^\`2"X%Y(\L
M!'(>XZZ,ARX%XZ_BC.*5XHSBE8R$CH5"KP!$0J\`2"]'`$@H+P$4*B\!&$*!
M!H5:@GF9V8$@1")%*"\`3"HO`%`B"-J)V8$O1`!,+T4`4"(,O8&_@,*"P(,@
M0"`!*"\`.+F`(@@J+P`\NX$H+P!,*B\`4-J!V8`O1`!,+T4`4"H*ZXT@12`+
MZYA"A$*%*@`B"(J!("\`3"(O`%#2A=&$+T``3"]!`%"1R)/)(D$H`^2,(`)R
M'N.H@(0B`W@>Z:GBBN*3XHKBDX2`@H,H02`O`1PB+P$@0H4&@5J">9G1A28O
M`#C2KP`\T8.UAB@,N8<J"LR%)`O.@B0O`$2]@B8O`$B_@]:!U8`H".N,+`GK
MGD*`0H$B!H*$*`(J`]J!V8`O1``X+T4`/$*&0H<N!20+>A[KJB`*(@OBB.*1
MXHCBD82!)D(D+P$D)B\!*$*`!H-NV>NAU8`B+P!$UJ\`2-6!*`PJ"[N$0H!"
M@2(O`%"Y@=*#T8(H!NN,*@?KG4*"0H,F!8:$*``J`=J#V8(O1`!$+T4`2$*$
M0H4J+P!((`ER'N.H)`@F">**XI/BBN*3@(,D0"0O`2PF+P$P0H`&@V[9ZZ'5
M@)'(D\DB3"`((@G2@]&"($`B02`+(@JS@$*"0H,F+P`\L8,@""()TH/1@B!`
M(D$@!.N((@7KF4*"0H,F`8:`(`@B"=*#T8(@0")!0H)"@R8)(`=R'N.HXH[B
ME^*.XI>`AR!`+"\!-"XO`3A"@`:';MGKH=V`0J\`.$*O`#PO2P`\("\`."(O
M`#S2A]&&)D`H02`*(@BS@$*&0H<N!;&'(`LB#-*'T88O0``X+T$`/"("ZXDF
M02P)ZYY"@$*!(@8N"X*'+"\`."XO`#S>@=V`+T8`1"]'`$A"@$*!(@<L!7X>
M[Z[BC.*5XHSBE8R%+$8H+P$\*B\!0$*&!H5NV>NAV8:7RYG,*$HN"]J,V8<D
M1"9%*`@J#KN$0J\`.$*O`#RWA"]$`#PH+P`X*B\`/"P*VHO9AB1$)D4N`.N/
M*`'KG$*O`#A"KP`\B(<O1``\*B\`."PO`#PN"MR+VX<D129&0H1"A2H++`E^
M'N^NXHKBD^**XI.,@R)&)"\!1"8O`4A"A@:#;MGKH=6&0J\`.$*O`#PO2``\
M+"\`."XO`#S>@]V"+T8`."]'`#PN"20.M8="@D*#)@<L+P!(O8,L+P`X+B\`
M/-Z#W8(O1@`X+T<`/"X$ZX\D"^N:($)"@D*#)@B&ARPO`#@N+P`\WH/=@B]&
M`#@O1P`\0H)"@R8'+@%\'NVOXHCBD>*(XI&.@2]'`$`@+P%,(B\!4$*&!H%N
MV>NAT89"AD*'+@[2A]&&+T``1"]!`$@L"2XO`$"_AD*O`$Q"KP!0(`N]@"]`
M`%`L+P!$+B\`2"`O`$S>KP!0W8`D1B9'+`+KCB(#ZYE"KP!$0J\`2(*&+T$`
M2"PO`$0N+P!((`K>B]V`)$8F1T*`0H$B"RP%?A[OKN*,XI7BC.*5C(4L1B@O
M`50J+P%80H8&A6[9ZZ'9AD*&0H<N"=J'V88@1")%+B\`0"@.N8="KP!$0J\`
M2"HO`#R[AR]'`$@L+P!$+B\`2"@(WHG=A"!&(D<J`.N-+`OKGD*O`#A"KP`\
MC(4O1@`\*"\`."HO`#PL"-J)V88@1")%0H1"A2H)+@-\'NVOXHKBD^**XI..
M@R!')"\!7"8O`6!"AP:#;MGKH=6'0J\`.$*O`#PO;P!``#PL+P`X+B\`/-Z#
MW8(O1@`X+T<`/"X()`ZUAT*"0H,F"[^#+"\`."XO`#S>@]V")$8F1RX$ZX\D
M">N:*$)"@D*#)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!?![MK^*(XI'BB.*1
MCH$O1P!`("\!9"(O`6A"A@:!;MGKH=&&0H9"ARX.TH?1AB]``#@O00`\+`@N
M+P!`OX9"KP!$0J\`2"`)O8`O0`!(+"\`."XO`#P@+P!$WJ\`2-V`(D8D1RP"
MZXXB"^N90J\`.$*O`#R"AB]!`#PL+P`X+B\`/"`)WHK=@")&)$="@$*!(@HL
M!7X>[Z[BC.*5XHSBE8R%+$8H+P%L*B\!<$*&!H5NV>NAV89"AD*'+@C:A]F&
M($0B12XO`$`H#KF'0J\`.$*O`#RWAR]'`#PL+P`X+B\`/"@(WHG=A"!&(D<J
M`.N-+`KKGD*O`#A"KP`\C(4O1@`\*"\`."HO`#PL"-J)V88@1")%0H1"A2H)
M+@M\'NVOXHKBD^**XI..@R!')"\!="8O`7A"AP:#;MGKH=6'E\N9S"AO`$`L
M"RX,WH/=@B9&*$<N""0.M8="@D*#)@J_@RP++@S>@]V")$8F1RX$ZX\D">N:
M*$)"@D*#)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!?![MK^*(XI'BB.*1CH$O
M1P!`("\!?"(O`8!"A@:!;MGKH=&&0H9"ARX.TH?1AB]``#@O00`\+`@N+P!`
MOX9"KP!$0J\`2"`)O8`O0`!(+"\`."XO`#P@+P!$WJ\`2-V`(D8D1RP"ZXXB
M"^N90J\`.$*O`#R"AB]!`#PL+P`X+B\`/"`)WHK=@")&)$="@$*!(@HL!7X>
M[Z[BC.*5XHSBE8R%+$8H+P&$*B\!B$*&!H5NV>NAV89"AD*'+@C:A]F&($0B
M12XO`$`H#KF'0J\`.$*O`#RWAR]'`#PL+P`X+B\`/"@(WHG=A"!&(D<J`.N-
M+`KKGD*O`#A"KP`\C(4O1@`\*"\`."HO`#PL"-J)V88@1")%0H1"A2H)+@M\
M'NVOXHKBD^**XI..@R!')"\!C"8O`9!"AP:#;MGKH=6'E\N9S"AO`$`L"RX,
MWH/=@B9&*$<N""0.M8="@D*#)@J_@RP++@S>@]V")$8F1RX$ZX\D">N:*$)"
M@D*#)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!?![MK^*(XI'BB.*1CH$O1P!`
M("\!E"(O`9A"A@:!;MGKH=&&0H9"ARX.TH?1AB]``#@O00`\+`@N+P!`OX9"
MKP!$0J\`2"`)O8`O0`!(+"\`."XO`#P@+P!$WJ\`2-V`(D8D1RP"ZXXB"^N9
M0J\`.$*O`#R"AB]!`#PL+P`X+B\`/"`)WHK=@")&)$="@$*!(@HL!7X>[Z[B
MC.*5XHSBE8R%+$8H+P&<*B\!H$*&!H5NV>NAV89"AD*'+@C:A]F&($0B12XO
M`$`H#KF'0J\`.$*O`#RWAR]'`#PL+P`X+B\`/"@(WHG=A"!&(D<J`.N-+`KK
MGD*O`#A"KP`\C(4O1@`\*"\`."HO`#PL"-J)V88@1")%0H1"A2H)+@M\'NVO
MXHKBD^**XI..@R!')"\!I"8O`:A"AP:#;MGKH=6'E\N9S"AO`$`L"RX,WH/=
M@B9&*$<N""0.M8="@D*#)@J_@RP++@S>@]V")$8F1RX$ZX\D">N:*$)"@D*#
M)@R&ARP*+@O>@]V")$8F1T*"0H,F"RX!?![MK^*(XI'BB.*1CH$D1R`O`:PB
M+P&P0H<&@6[9ZZ'1AT*O`#A"KP`\+TX`/"PO`#@N+P`\WH'=@"]&`#@O1P`\
M+@@@"K&'0H!"@2('NX$L+P`X+B\`/-Z!W8`O1@`X+T<`/"X"ZX\@"^N8*$!"
M@$*!(@R"ARPO`#@N+P`\WH'=@"]&`#@O1P`\0H9"ARXO`#P@"7(>XZCBC.*5
MXHSBE8"%(D`H+P&T*B\!N$*`!H5NV>NAV8`O1`!$+T4`2$*$0H4J""`O`$0B
M+P!(TH71A"]``$0O00!((@HH";F!0H1"A2H!MX4@+P!$(B\`2-*%T80@!W@;
MZ*@H!NN,B(`J!^N-(`6`A)?+F<PH0=G`(@/DB2H"<![AK8J!*`/AK.**XI/B
MBN*3BH(L18B#0J\`3$*O`%`O1`!0("\!O"(O`<!"@@:!;MGKH=&"0H)"@R8*
MTH/1@B8)N8,@0T*"0H,F"+^#TH/1@B`,=!ODJ"0+ZXJ$@"8,ZXL@`X""0H)"
M@R8!UH`@!^2((@9Z'NNI@H`@!^NHXH[BE^*.XI>"AB!!@(<D0$*O`#A"KP`\
M+T``/"PO`<0N+P'(0H`&AX\;O-S=@$*`0H$B"=Z!W8`O1@!$+T<`2"H.(@B*
M@2P*B(8B"\*%(`S`A"XO`$S.KP`X+"\`4,RO`#PH`8B'*@"*ABXO`$3:KP!(
MV8<B`W`;X*D@`NN(@($B`^N)*`&(@$*`0H$B!=*$*@SDC2@+?![MK(B%*@SM
MK2P++@SBCN*7XH[BEXB&+T0`0(J'*$5"KP!$0J\`2"]%`$@N"(Z$*`J(A<Z"
MR(,J+P`XRJ\`1"P*S*\`2(Z%+T<`<(B&+T0`="@O`<PJ+P'00H8&A8\;O-S9
MAB!$(D4H+P!,*B\`4"P(VHG9AB!$(D4H+P!P*B\`="P(VHG9AB!$(D4N`7@;
MZ*\L`.N.C(<N`>N/CH8@1T*&0H<N"=Z(*@/DC2!%*`)Z'NNL*@B*A"1%*`-Z
M'NNL)D0H`BH#XHSBE>*,XI4@1")%*@HD"(J"+T4`+"8+*`F&A"Q#0J\`3$*O
M`%`O0P!0*"\`0(B%*@R*@\B`RH$@12HO`$3*KP!,)`S$@XB%+T0`<"8(AH(O
M0P!T*"\!U"HO`=A"@@:%CQN\W-F"($0B128O`#@H+P`\*@C8B=>%($,B1"0O
M`'`F+P!T*`C6B=6$($(B0RH'=!ODK2@&ZXR(A2H'ZXV*A"!%0H1"A2H)VH@F
M`>2+($,D`'8>YZHF"(:")$,D`78>YZHF0B0`)@'BBN*3XHKBDR!"(D,F"B`(
MAH`O0P!`(@LD"8*"*$%"KP`X0J\`/"]!`#PF+P`LAJ\`0"0.A('&AB)#Q(<F
M+P!,QJ\`."`.P($B"8*#+T$`<(2`+T(`="0O`=PF+P'@0H`&@X\;O-S5@"!"
M(D,B+P!$)"\`2"8(U(G3@R!!(D(@+P!P(B\`="0(THG1@B!`(D$F!7`;X*LD
M!.N*A(,F!>N+AH(@0T*"0H,F"=:((@?DB2!!(`9R'N.H(@B"@"1!(`=R'N.H
M)D`@!B('XHCBD>*(XI$@0")!(@HL"(*&+T$`+"X+(`F.@"Q'0J\`1$*O`$@O
M1P!((B\`0(*O`"P@#("'PH0B0<"%(B\`.,*O`$0L#,R'+@F.@2]'`'"`AB]`
M`'0@+P'D(B\!Z$*&!H&/&[S<T88@0")!("\`3"(O`%`L"-*)T88@0")!("\`
M<"(O`'0L"-*)T88@0")!(@-^&^ZI(`+KB("!(@/KB8*`($%"@$*!(@G2B"P%
MY(X@1BX$?![MKRP(C(<D1BX%?![MKR9'+`0N!>*.XI?BCN*7($8B1RX**`B.
MA"]'`$`J"RP)BH8H14*O`$Q"KP!0+T4`4"XO`"R.KP!`+`Z,A<Z"(D?,@RXO
M`$3.KP!,*`[(A2H)BH<O10!PC(0O1@!T+"\!["XO`?!"A`:'CQN\W-V$($8B
M1RHO`#@L+P`\+@C<B=N'($4B1B@O`'`J+P!T+`C:B=F&($0B12X!>!OHKRP`
MZXZ,ARX!ZX^.AB!'0H9"ARX)WH@J`^2-($4H`GH>ZZPJ"(J$)$4H`WH>ZZPF
M1"@"*@/BC.*5XHSBE2!$(D4J"B0(BH(O10`L)@LH"8:$+$-"KP`X0J\`/"]#
M`#PJ+P!`BJ\`+"@,B(/*@")%R($J+P!,RJ\`."0,Q(,F"8:%+T,`<(B"+T0`
M="@O`?0J+P'X0H(&A8\;O-S9@B!$(D4F+P!$*"\`2"H(V(G7A2!#(D0D+P!P
M)B\`="@(UHG5A"!"(D,J!W0;Y*TH!NN,B(4J!^N-BH0@14*$0H4J"=J()@'D
MBR!#)`!V'N>J)@B&@B1#)`%V'N>J)D(D`"8!XHKBD^**XI,@0B)#)@H@"(:`
M+T,`0"(+)`F"@BA!0J\`1$*O`$@O00!()B\`+(:O`$`D#H2!QH8B0\2')B\`
M.,:O`$0@#L"!(@F"@R]!`'"$@"]"`'0D+P'\)B\"`$*`!H./&[S<U8`@0B)#
M(B\`3"0O`%`F"-2)TX,@02)"("\`<"(O`'0D"-*)T8(@0")!)@5P&^"K)`3K
MBH2#)@7KBX:"($-"@D*#)@G6B"('Y(D@02`&<A[CJ"((@H`D02`'<A[CJ"9`
M(`8B!^*(XI'BB.*1($`B02(*+`B"AB]!`"PN"R`)CH`L1T*O`$Q"KP!0+T<`
M4"(O`$""KP`L(`R`A\*$(D'`A2(O`$3"KP!,+`S,ARX)CH$O1P!P@(8O0`!T
M("\"!"(O`@A"A@:!CQN\W-&&($`B02`O`#@B+P`\+`C2B=&&($`B02`O`'`B
M+P!T+`C2B=&&($`B02(#?AONJ2`"ZXB`@2(#ZXF"@"!!0H!"@2()TH@L!>2.
M($8N!'P>[:\L"(R')$8N!7P>[:\F1RP$+@7BCN*7XH[BER!&(D<N"B@(CH0O
M1P!`*@LL"8J&*$5"KP`X0J\`/"]%`#PN+P`LCJ\`0"P.C(7.@B)'S(,N+P!,
MSJ\`."@.R(4J"8J'+T4`<(R$+T8`="PO`@PN+P(00H0&AX\;O-S=A"!&(D<J
M+P!$+"\`2"X(W(G;AR!%(D8H+P!P*B\`="P(VHG9AB!$(D4N`7@;Z*\L`.N.
MC(<N`>N/CH8@1T*&0H<N"=Z(*@/DC2!%*`)Z'NNL*@B*A"1%*`-Z'NNL)D0H
M`BH#XHSBE>*,XI4@1")%*@HD"(J"+T4`+"8+*`F&A"Q#0J\`1$*O`$@O0P!(
M*B\`0(JO`"PH#(B#RH`B1<B!*B\`.,JO`$0D#,2#)@F&A2]#`'"(@B]$`'0H
M+P(4*B\"&$*"!H6/&[S<V8(@1")%)B\`3"@O`%`J"-B)UX4@0R)$)"\`<"8O
M`'0H"-:)U80@0B)#*@=T&^2M*`;KC(B%*@?KC8J$($5"A$*%*@G:B"8!Y(L@
M0R0`=A[GJB8(AH(D0R0!=A[GJB9")``F`>**XI/BBN*3($(B0R8*(`B&@"]#
M`$`B"R0)@H(H04*O`$Q"KP!0+T$`4"8O`"R&KP!`)`Z$@<:&(D/$AR8O`$3&
MKP!,(`[`@2()@H,O00!PA(`O0@!T)"\"'"8O`B!"@`:#CQN\W-6`($(B0R(O
M`#@D+P`\)@C4B=.#($$B0B`O`'`B+P!T)`C2B=&"($`B028%<!O@JR0$ZXJ$
M@R8%ZXN&@B!#0H)"@R8)UH@B!^2)($$@!G(>XZ@B"(*`)$$@!W(>XZ@F0"`&
M(@?BB.*1XHCBD2!`(D$B"BP(@H8O00`L+@L@"8Z`+$="KP`X0J\`/"]'`#PB
M+P!`@J\`+"`,@(?"A")!P(4B+P!,PJ\`."P,S(<N"8Z!+T<`<("&+T``="`O
M`B0B+P(H0H8&@8\;O-S1AB!`(D$@+P!$(B\`2"P(THG1AB!`(D$@+P!P(B\`
M="P(THG1AB!`(D$B`WX;[JD@`NN(@($B`^N)@H`@04*`0H$B"=*(+`7DCB!&
M+@1\'NVO+`B,AR1&+@5\'NVO)D<L!"X%XH[BE^*.XI<@1B)'+@HH"(Z$+T<`
M0"H++`F*ABA%0J\`1$*O`$@O10!(+B\`+(ZO`$`L#HR%SH(B1\R#+B\`.,ZO
M`$0H#LB%*@F*AR]%`'",A"]&`'0L+P(L+B\",$*$!H>/&[S<W80@1B)'*B\`
M3"PO`%`N"-R)VX<@12)&*"\`<"HO`'0L"-J)V88@1")%+@%X&^BO+`#KCHR'
M+@'KCXZ&($="AD*'+@G>B"H#Y(T@12@">A[KK"H(BH0D12@#>A[KK"9$*`(J
M`^*,XI7BC.*5($0B12H*)`B*@B]%`"PF"R@)AH0L0T*O`$Q"KP!0+T,`4"HO
M`$"*KP`L*`R(@\J`(D7(@2HO`$3*KP!,)`S$@R8)AH4O0P!PB((O1`!T*"\"
M-"HO`CA"@@:%CQN\W-F"($0B128O`#@H+P`\*@C8B=>%($,B1"0O`'`F+P!T
M*`C6B=6$($(B0RH'=!ODK2@&ZXR(A2H'ZXV*A"!%0H1"A2H)VH@F`>2+($,D
M`'8>YZHF"(:")$,D`78>YZHF0B0`)@'BBN*3XHKBDR!"(D,F"B`(AH`O0P!`
M(@LD"8*"*$%"KP`X0J\`/"]!`#PF+P`LAJ\`0"0.A('&AB)#Q(<F+P!,QJ\`
M."`.P($B"8*#+T$`<(2`+T(`="0O`CPF+P)`0H`&@X\;O-S5@"!"(D,B+P!$
M)"\`2"8(U(G3@R!!(D(@+P!P(B\`="0(THG1@B!`(D$F!7`;X*LD!.N*A(,F
M!>N+AH(@0T*"0H,F"=:((@?DB2!!(`9R'N.H(@B"@"1!(`=R'N.H)D`@!B('
MXHCBD>*(XI$@0")!(@HL"(*&+T$`+"X+(`F.@"Q'0J\`1$*O`$@O1P!((B\`
M0(*O`"P@#("'PH0B0<"%(B\`.,*O`$0L#,R'+@F.@2]'`'"`AB]``'0@+P)$
M(B\"2$*&!H&/&[S<T88@0")!("\`3"(O`%`L"-*)T88@0")!("\`<"(O`'0L
M"-*)T88@0")!(@-^&^ZI(`+KB("!(@/KB8*`($%"@$*!(@G2B"P%Y(XB1BX$
M?![MKRP)C(<@1BX%?![MKR)'XHSBE>*,XI4N"(Z$+T<`0"P)C(4H1D*O`$Q"
MKP!0+T8`4"XO`"R.KP!`+`XH#(R$SH+,@R!&*B\`1,JO`$PL#LR$CH4O1P!P
M+@B.AB]'`'0H+P),*B\"4$*&!H6/&[S<V88@1")%*"\`."HO`#PL"-J)V88@
M1")%+"\`<"XO`'0H"-Z)W80J`7@;Z*TL`.N.C(4J`>N-BH8@197*E\M'\'@`
M+@/DCRP">![IKHR'+@/IK^**XI/BBN*3C((L1H:'0J\`.$*O`#PO0P`\*`:(
MKP!`*@R*@\B`RH$L+P!,S*\`."X,SH.,A(Z%*"\"5"HO`EA"@@:%CQN\W-F"
M($0B12@O`$0J+P!()`C:B=F"VH?9AB]$`$0O10!(*@KKC2P+ZYXB1D*&0H<N
M"8Z%*"\`1"HO`$C:A]F&+T0`<"]%`'21R)/)(D4J`>2-*`!\'NVLB(4J`>VM
MXHCBD>*(XI&(@(*%0J\`1$*O`$@O00!()`Z$A(:!+@K$AR`+QH`L+P`XS*\`
M1"`O`#S`@2@"B(8J`XJ`)"\"7"8O`F!"A@:#CQN\W-6&+B\`3-:O`%#5A]:%
MU80@".N(+`GKGD*$0H4J!HJ`+`(N`]Z%W80O1@!,+T<`4$*&0H<N+P!0(`MT
M'N6H)`HF"^**XI/BBN*3@(,F0"0O`F0F+P)H0H0&@\IBP=;5A"HO`#C6KP`\
MU84H`+.$0H!"@2(O`'2Y@=*#T8(H!NN,*@?KG4*"0H,F!8:$*``J`=J#V8(O
M1`!P+T4`=$*$0H4J+P!T(`ER'N.H)`@F">**XI/BBN*3@(,D0"0O`FPF+P)P
M0H`&@\IBP=;5@"`O`$0B+P!(TH/1@B!`(D$@"R(*LX!"@D*#)@>Q@R`((@G2
M@]&"($`B02`$ZX@B!>N90H)"@R8!AH`@""()TH/1@B!`(D%"@D*#)@D@!W(>
MXZCBCN*7XH[BEX"'($`L+P)T+B\">$*`!H?*8L'6W8!"KP`X0J\`/"]+`#P@
M+P`X(B\`/-*'T88F0"A!(`HB"+.`0H9"ARX%L8<@"R(,TH?1AB]``#@O00`\
M(@+KB29!+`GKGD*`0H$B!BX+@H<L+P`X+B\`/-Z!W8`O1@!$+T<`2$*`0H$B
M!RP%?A[OKN*,XI7BC.*5C(4L1B@O`GPJ+P*`0H8&A<IBP=;9AI?+F<PH2BX+
MVHS9AR1$)D4H""H.NX1"KP`X0J\`/+>$+T0`/"@O`#@J+P`\+`K:B]F&)$0F
M12X`ZX\H`>N<0J\`.$*O`#R(AR]$`#PJ+P`X+"\`/"X*W(O;AR1%)D9"A$*%
M*@LL"7X>[Z[BBN*3XHKBDXR#(D8D+P*$)B\"B$*&!H/*8L'6U89"KP`X0J\`
M/"](`#PL+P`X+B\`/-Z#W8(O1@`X+T<`/"X))`ZUAT*"0H,F!RPO`$B]@RPO
M`#@N+P`\WH/=@B]&`#@O1P`\+@3KCR0+ZYH@0D*"0H,F"(:'+"\`."XO`#S>
M@]V"+T8`."]'`#Q"@D*#)@<N`7P>[:_BB.*1XHCBD8Z!+T<`0"`O`HPB+P*0
M0H8&@<IBP=;1AD*&0H<N#M*'T88O0`!$+T$`2"P)+B\`0+^&0J\`3$*O`%`@
M"[V`+T``4"PO`$0N+P!(("\`3-ZO`%#=@"1&)D<L`NN.(@/KF4*O`$1"KP!(
M@H8O00!(+"\`1"XO`$@@"MZ+W8`D1B9'0H!"@2(++`5^'N^NXHSBE>*,XI6,
MA2Q&*"\"E"HO`IA"A@:%RF+!UMF&0H9"ARX)VH?9AB!$(D4N+P!`*`ZYAT*O
M`$1"KP!(*B\`/+N'+T<`2"PO`$0N+P!(*`C>B=V$($8B1RH`ZXTL"^N>0J\`
M.$*O`#R,A2]&`#PH+P`X*B\`/"P(VHG9AB!$(D5"A$*%*@DN`WP>[:_BBN*3
MXHKBDXZ#($<D+P*<)B\"H$*'!H/*8L'6U8="KP`X0J\`/"]O`$``/"PO`#@N
M+P`\WH/=@B]&`#@O1P`\+@@D#K6'0H)"@R8+OX,L+P`X+B\`/-Z#W8(D1B9'
M+@3KCR0)ZYHH0D*"0H,F#(:'+`HN"]Z#W8(D1B9'0H)"@R8++@%\'NVOXHCB
MD>*(XI&.@2]'`$`@+P*D(B\"J$*&!H'*8L'6T89"AD*'+@[2A]&&+T``."]!
M`#PL""XO`$"_AD*O`$1"KP!((`F]@"]``$@L+P`X+B\`/"`O`$3>KP!(W8`B
M1B1'+`+KCB(+ZYE"KP`X0J\`/(*&+T$`/"PO`#@N+P`\(`G>BMV`(D8D1T*`
M0H$B"BP%?A[OKN*,XI7BC.*5C(4L1B@O`JPJ+P*P0H8&A<IBP=;9AD*&0H<N
M"-J'V88@1")%+B\`0"@.N8="KP`X0J\`/+>'+T<`/"PO`#@N+P`\*`C>B=V$
M($8B1RH`ZXTL"NN>0J\`.$*O`#R,A2]&`#PH+P`X*B\`/"P(VHG9AB!$(D5"
MA$*%*@DN"WP>[:_BBN*3XHKBDXZ#($<D+P*T)B\"N$*'!H/*8L'6U8>7RYG,
M*&\`0"P++@S>@]V")D8H1RX()`ZUAT*"0H,F"K^#+`LN#-Z#W8(D1B9'+@3K
MCR0)ZYHH0D*"0H,F#(:'+`HN"]Z#W8(D1B9'0H)"@R8++@%\'NVOXHCBD>*(
MXI&.@2]'`$`@+P*\(B\"P$*&!H'*8L'6T89"AD*'+@[2A]&&+T``."]!`#PL
M""XO`$"_AD*O`$1"KP!((`F]@"]``$@L+P`X+B\`/"`O`$3>KP!(W8`B1B1'
M+`+KCB(+ZYE"KP`X0J\`/(*&+T$`/"PO`#@N+P`\(`G>BMV`(D8D1T*`0H$B
M"BP%?A[OKN*,XI7BC.*5C(4L1B@O`L0J+P+(0H8&A<IBP=;9AD*&0H<N"-J'
MV88@1")%+B\`0"@.N8="KP`X0J\`/+>'+T<`/"PO`#@N+P`\*`C>B=V$($8B
M1RH`ZXTL"NN>0J\`.$*O`#R,A2]&`#PH+P`X*B\`/"P(VHG9AB!$(D5"A$*%
M*@DN"WP>[:_BBN*3XHKBDXZ#($<D+P+,)B\"T$*'!H/*8L'6U8>7RYG,*&\`
M0"P++@S>@]V")D8H1RX()`ZUAT*"0H,F"K^#+`LN#-Z#W8(D1B9'+@3KCR0)
MZYHH0D*"0H,F#(:'+`HN"]Z#W8(D1B9'0H)"@R8++@%\'NVOXHCBD>*(XI&.
M@2]'`$`@+P+4(B\"V$*&!H'*8L'6T89"AD*'+@[2A]&&+T``."]!`#PL""XO
M`$"_AD*O`$1"KP!((`F]@"]``$@L+P`X+B\`/"`O`$3>KP!(W8`B1B1'+`+K
MCB(+ZYE"KP`X0J\`/(*&+T$`/"PO`#@N+P`\(`G>BMV`(D8D1T*`0H$B"BP%
M?A[OKN*,XI7BC.*5C(4L1B@O`MPJ+P+@0H8&A<IBP=;9AD*&0H<N"-J'V88@
M1")%+B\`0"@.N8="KP`X0J\`/+>'+T<`/"PO`#@N+P`\*`C>B=V$($8B1RH`
MZXTL"NN>0J\`.$*O`#R,A2]&`#PH+P`X*B\`/"P(VHG9AB!$(D5"A$*%*@DN
M"WP>[:_BBN*3XHKBDXZ#($<D+P+D)B\"Z$*'!H/*8L'6U8>7RYG,*&\`0"P+
M+@S>@]V")D8H1RX()`ZUAT*"0H,F"K^#+`LN#-Z#W8(D1B9'+@3KCR0)ZYHH
M0D*"0H,F#(:'+`HN"]Z#W8(D1B9'0H)"@R8++@%\'NVOXHCBD>*(XI&.@2]'
M`$`@+P+L(B\"\$*&!H'*8L'6T89"AD*'+@[2A]&&+T``."]!`#PL""XO`$"_
MAD*O`$1"KP!((`F]@"]``$@L+P`X+B\`/"`O`$3>KP!(W8`B1B1'+`+KCB(+
MZYE"KP`X0J\`/(*&+T$`/"PO`#@N+P`\(`G>BMV`(D8D1T*`0H$B"BP%?A[O
MKN*,XI7BC.*5C(4H+P+T*B\"^$*'!H7*8L'6V8<O1`!$+T4`2$*O`#A"KP`\
M+T@`/"@O`#@J+P`\+B\`1-JO`$C9AR!$(D4H+P!`O81"KP`X0J\`/+>$+T0`
M/"@O`#@J+P`\+@C:B=F')D0H12@*>AOJK"!$*`#KC"X(B(<J"NN-BH0H#-B%
M+@-Z'NNOXHKBD^**XI,J!XJ#)"\"_"8O`P!"AP:#RF+!UM6'($(B0R0O`#`F
M+P`T+@C6B=6')D(H0Y'(D\DB;P!`)`@F"2X+UHS5AR!"(D,N!KN'E\N9S"0*
MOX(H0B0()@DN"]:,U8<@0B)#)@1T&^2K0H*$@RX$ZX\F!X:")&\`7$*2UHDE
M0P`$0JH`"-BO`&0E1``,)`%V'N>JXHCBD>*(XI$@`H"!0JH`$-"O`%@E0``4
M0JH`&-JO`&PE10`<0JH`(-RO`'PE1@`D(B\#!"!O`(`@$+"!9@I,WWS\3^\"
MW$YU8?___ZN22'@`?&'___^L>$*0(7QG12,!``1"J``((7SOS:N)``Q"J``0
M(7R8NMS^`!1"J``8(7P0,E1V`!Q"J``@(7S#TN'P`"1"J``H0J@`+$*H`#!"
MJ``T0J@`>%B/(`A.=4CG/SHF;P`L)&\`,"AO`#0@:P`H(FL`+"(,6\!)P"P`
M+@'>A]V&WH?=AMZ'W89"@D*#)@?6B2PK`#`N*P`T*`@J"9J#F8)C!D*%4H?=
MA2="`"@G0P`L*`#GC"8!>AWJJX:$)`#JJB`"(@/2A]&&)T``,"=!`#0@*P!X
M9EQ-ZP`X>#^XC&P``+Q)[/_`)@SLBR0#4H+MBM2*2'@`0"\*+PYA____JA9%
MZ@!`+PMA____RW)/[P`0M(IFWNV+F<,O#"\"+PYA____J?(G3`!X3^\`#$S?
M7/Q.=71`E("YPFTX3>L`."\"+PI(=@@`8?___ZG*(`+0JP!X)T``>$_O``QR
M0+*`9LR9PM7"+PMA____RQ)8CV``_VHD#$WK`#@O`B\*2'8(`&'___^ID"`"
MT*L`>"=``'A/[P`,<D"R@&:28,0D"B\,+P(O#F'___^I;"=,`'A/[P`,8`#_
M>$CG/C@F;P`D)&\`*"0J`"@F*@`L*"H`,"HJ`#0@`B(#XHCBD>*(XI'BB.*1
M?#_"ADGJ`#@@`5*`&;S_@!@`<CBR@&P``1Y!]`@`<D"2@'P$O(%C``(R<`*P
M@6,``B!*@68``>XO"F'____*7$*<0IQ"G$*<0IQ"G$*<0IQ"G$*<0IQ"G$*<
M0I18CR`%?!CLJ!5``'`@!"(%,@1(015!`'$@!"(%$@3@F15!`'(510!S(`/L
MJ!5``'0@`B(#,@)(015!`'4@`B(#$@+@F15!`'850P!W+PIA____R>P6J@`$
M%VH`!0`!%VH`!@`"%VH`!P`#%VH`#``$%VH`#0`%%VH`#@`&%VH`#P`'%VH`
M%``(%VH`%0`)%VH`%@`*%VH`%P`+%VH`'``,%VH`'0`-%VH`'@`.%VH`'P`/
M%VH`)``0%VH`)0`1%VH`)@`2%VH`)P`36(\O2@`D3-\<?&#___^GUG(XDH`O
M`4*G2'0(`&'___^J'$_O``P@!7P8[*@50`!P(`0B!3($2$$500!Q(`0B!1($
MX)D500!R%44`<R`#[*@50`!T(`(B`S("2$$500!U(`(B`Q("X)D500!V%4,`
M=R\*8?___\C^%JH`!!=J``4``1=J``8``A=J``<``Q=J``P`!!=J``T`!1=J
M``X`!A=J``\`!Q=J`!0`"!=J`!4`"1=J`!8`"A=J`!<`"Q=J`!P`#!=J`!T`
M#1=J`!X`#A=J`!\`#Q=J`"0`$!=J`"4`$1=J`"8`$A=J`"<`$UB/+TH`)$S?
M''Q@____INA"$"\*8?___\AN0IQ"G$*<0IQ"G$*<0IQ"G$*<0IQ"G$*<0IQ"
ME%B/8`#^$$)858%G`/WB8,I"F%F!<`*P@6(`_<Y@Z"\-2_L!<```:K0@=0%P
M```!'"\0+R\`%"\O`!0O+P`48?___Z>^3^\`$"I?3G5.<4Y6```O#4O[`7``
M`&J`*F[__$Y>3G4``@`!)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C
M+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!0
M15),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!
M3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`#$`;'-E96L@9F%I;&5D`')E860@
M9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M<`!414U01$E2`%1-
M4`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P`E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R
M;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)3
M24].`#$N,#8S`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)
M0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)
M3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S
M:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`[
M"B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?
M;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@
M,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H
M)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/
M5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H
M)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U
M9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@
M)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N
M("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M
M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D
M=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL
M96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN
M+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@
M/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I
M.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE
M(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R
M=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@
M)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M
M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@
M:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?
M<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@
M,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!
M1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T
M<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<
M,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<
M,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S
M="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@
M,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F
M<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T
M87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*
M<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP
M86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@
M>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D
M=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z
M("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]
M*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M
M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D
M8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A
M9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@
M("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL
M92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M
M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*
M:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*
M?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E
M860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D
M8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE
M<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50
M871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z
M.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T
M92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@
M/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D
M97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*
M;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^
M(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR
M87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T[
M"B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&
M24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT
M96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O
M("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]
M"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI
M('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN
M960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@
M)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA
M;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S
M:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T
M*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II
M<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D
M9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A
M<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@
M)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@
M)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H
M)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D
M1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE
M7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I
M>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F
M(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE
M+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A
M<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E
M;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF
M)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N
M86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G
M;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO
M)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB
M4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I
M9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@``0T%#2$4`<&5R;'AS:2YC````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````A"```(,0````!```#-`````$`
M``-$`````0```TX````,```8K`````T``',8````&0``W(@````;````!```
M`!H``-R,````'`````0````$```!B&___O4```0D````!0``"R`````&```%
M``````H```39````"P```!`````5``````````,``-V@`````@```MP````4
M````!P```!<``!70````!P``$8`````(```$4`````D````,````'@````AO
M___["````6____X``!#`;____P````)O___P```/^F____D```!/````````
M````````````````````````````````````````````````W)``````````
M````&/```!D$```9&```&2P``!E````95```&6@``!E\```9D```&:0``!FX
M```9S```&>```!GT```:"```&AP``!HP```:1```&E@``!IL```:@```&I0`
M`!JH```:O```&M```!KD```:^```&PP``!L@```;-```&T@``!M<```;<```
M&X0``!N8```;K```&\```!O4```;Z```&_P``!P0```<)```'#@``!Q,```<
M8```''0``!R(```<G```'+```!S$```<V```'.P``!T````=%```'2@``!T\
M```=4```'60``!UX```=C```':```'6C```=K````````.`8````````````
M``````#@!`````````````#@&````````#>D`````````````.`8``#@'```
M<S@```````!S1P``=@0``'-C```F7```LX(``'-#``!S>```<X0``'.&``!S
MCP``<YP``'.>``!TIP``<Z```'.I``!SL0``<[H``',R``!ST0``<]T``'/G
M``!S\0``<_L``'0,``!T'@``="D``'0Y``!T2@``=$P``'19``#@"```=&4`
M`'1U``!T?```=!<``'2!``!T-```=(D``'2-``!TD@``=)L``'2@``!TI0``
M=*X``'3I````````=3P``'5!``!U1@``=5$``'5@``!U;@``=7\``'6!``!U
MA@``=8@``'6=````````=<0``.`@``#@)```<\$``'8%``!V"```X"@``'1P
M````````X!(``'.!````````X`0*4$%2+G!M"@````!V"P``1T-#.B`H1&5B
M:6%N(#$S+C(N,"TQ-BXQ*2`Q,RXR+C```"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?
M9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M```````````````````````````+`````0````(```$T```!-`````T`````
M``````````$`````````$P````<````"```!1````40````D````````````
M```$`````````"8````'`````@```6@```%H````(```````````````!```
M```````X````!0````(```&(```!B````IP````&``````````0````$````
M-&____8````"```$)```!"0```#<````!@`````````$````!````#X````+
M`````@``!0````4````&(`````<````"````!````!````!&`````P````(`
M``L@```+(```!-D```````````````$`````````3F____\````"```/^@``
M#_H```#$````!@`````````"`````@```%MO___^`````@``$,```!#`````
MP`````<````"````!`````````!J````!`````(``!&````1@```!%`````&
M``````````0````,````=`````0```!"```5T```%=````+<````!@```!4`
M```$````#````'X````!````!@``&*P``!BL````)@```````````````@``
M``````!Y`````0````8``!C4```8U```!-@```````````````0````4````
MA`````$````&```=K```':P``%5L```````````````$`````````(H````!
M````!@``<Q@``',8````%@```````````````@````````"0`````0````(`
M`',N``!S+@``0%X```````````````(`````````F`````$````"``"SC```
MLXP````$```````````````"`````````*(````.`````P``W(@``+R(````
M!````````````````@````0```"N````#P````,``-R,``"\C`````0`````
M``````````(````$````N@````8````#``#<D```O)````$0````!P``````
M```$````"````,,````!`````P``W:```+V@```"8```````````````!```
M``0```#(`````0````,``.````#``````!@```````````````0`````````
MS@````@````#``#@&```P!@````4```````````````$`````````-,````!
M````,````````,`8````(0```````````````0````$````!`````P``````
;``````#`.0```-P```````````````$`````
